Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(934)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutBlock.h

Issue 1573133002: Need to examine the *bottom* of fragmented content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Slim down the patch; back out columnSetAtBlockOffset() changes. This was already broken prior to th… Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutBlock.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutBlock.h b/third_party/WebKit/Source/core/layout/LayoutBlock.h
index 2ae34b93f839fef30594c5d818e5b9ad6f845d69..20f5e7277ef423e3e08f350ffc82089667930185 100644
--- a/third_party/WebKit/Source/core/layout/LayoutBlock.h
+++ b/third_party/WebKit/Source/core/layout/LayoutBlock.h
@@ -473,9 +473,9 @@ protected:
LayoutUnit nextPageLogicalTop(LayoutUnit logicalOffset, PageBoundaryRule) const;
// Paginated content inside this block was laid out.
- // |logicalTopOffsetAfterPagination| is the logical top offset of the child content after
- // applying any forced or unforced break, if needed.
- void paginatedContentWasLaidOut(LayoutUnit logicalTopOffsetAfterPagination);
+ // |logicalBottomOffsetAfterPagination| is the logical bottom offset of the child content after
+ // applying any forced or unforced breaks as needed.
+ void paginatedContentWasLaidOut(LayoutUnit logicalBottomOffsetAfterPagination);
// Adjust from painting offsets to the local coords of this layoutObject
void offsetForContents(LayoutPoint&) const;

Powered by Google App Engine
This is Rietveld 408576698